<?php

namespace Teknisa\DF\Modules\Entrada\SincronizacaoNFSe\Utilities;

use Teknisa\Libs\Util\Utilities;

//use Teknisa\Libs\Util\Utilities as UtilGeral;

class Util {
    
    const DEV_LINK  = 'http://midiatest.teknisa.com/files/';
    const PROD_LINK = 'http://midia.teknisa.com/files/';
    
    public static function decrypt($text, $salt = 'teknisa'){
        return Utilities::zeedhiDecrypt($text, $salt);
    }
    
    public static function getDadosGeracao($connection, $cdempresa, $cdinscmuni, $nrorg) {
        $sql = "SELECT NVL(M.CDMUNICSIAFI, I.CDMUNICIPIO) AS CDMUNICIPIO,
                       M.CDMUNICIBGE,
                       I.SGESTADO,
                       I.CDPAIS,
                       I.NRORG
              FROM INSCRMUNICIP I
              JOIN MUNICIPIO M
                    ON  I.CDPAIS      = M.CDPAIS
                    AND I.SGESTADO    = M.SGESTADO
                    AND I.CDMUNICIPIO = M.CDMUNICIPIO
                    AND I.NRORG       = M.NRORG
              WHERE I.CDEMPRESA  = :CDEMPRESA
                AND I.CDINSCMUNI = :CDINSCMUNI
                AND I.NRORG      = :NRORG";
        
        if(is_array($cdempresa))    $cdempresa = $cdempresa[0];
        if(is_array($cdinscmuni))   $cdinscmuni = $cdinscmuni[0];
    
        $params = array(
            "CDEMPRESA"  => $cdempresa,
            "CDINSCMUNI" => $cdinscmuni,
            "NRORG"      => $nrorg
        );
        
        $std = $connection->prepare($sql);
        $std->execute($params);
        $dataset = $std->fetchAll();
        return (count($dataset) > 0) ? $dataset[0] : null;
    }
    
    private static function getInscrMunicip($connection, $cdinscmuni, $cdempresa, $nrorg) {
        $sql = 'SELECT CDINSCMUNI,
                CDEMPRESA,
                NRORG,
                DSDIRCERTIFICADO AS DSDIRCERT
        FROM PARAMNFSEINSCMUNI
        WHERE CDINSCMUNI = :P_CDINSCMUNI
        AND CDEMPRESA    = :P_CDEMPRESA
        AND NRORG        = :P_NRORG';
        
        $params = array(
            'P_CDINSCMUNI' => $cdinscmuni,
            'P_CDEMPRESA'  => $cdempresa,
            'P_NRORG'      => $nrorg
        );

        $query = $connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }

    public static function getDataSetCertificadoFileServer($connection, $cdinscmuni, $cdempresa, $nrorg, $fileserverlink, $mode = 'prod') {
        $inscrMunicip      = self::getInscrMunicip($connection, $cdinscmuni, $cdempresa, $nrorg);
        if($inscrMunicip[0]) {
            $inscrMunicip = $inscrMunicip[0];
            $filesString  = $inscrMunicip['DSDIRCERT'];
            
        }
        else throw new \Exception("Certificado não encontrado.");
        $filesArray = array();
        $array = array_filter(explode('<', $filesString));
        $count = 0;
        foreach ($array as $element) {
            $element = explode('>', $element);
            $file = array("fileName" => $element[0]);
            $file["path"] = ($mode === 'prod') ? $fileserverlink.$element[1] : self::DEV_LINK.$element[1];
            array_push($filesArray, $file);
            $count++;
        }
        return $filesArray;
    }
    
    public static function getLocalServidor($connection, $cdempresa, $cdinscmuni, $nrorg) {
        $sql = "SELECT IDLOCALSERVIDOR
                  FROM PARAMNFSEINSCMUNI
                 WHERE CDEMPRESA  = :P_CDEMPRESA
                   AND CDINSCMUNI = :P_CDINSCMUNI
                   AND NRORG      = :P_NRORG";
                   
        $params = array(
            "P_CDEMPRESA"  => $cdempresa,
            "P_CDINSCMUNI" => $cdinscmuni,
            "P_NRORG"      => $nrorg
        );
        
        $std = $connection->prepare($sql);
        $std->execute($params);
        $dataset =  $std->fetchAll();
         if (is_array($dataset) && count($dataset) > 0) {
            return $dataset[0]["IDLOCALSERVIDOR"];
        }
        else {
            return null;
        }
         
    }
    
    public static function getSenhaCertificadoDigital($connection, $cdempresa, $cdinscmuni, $nrorg) {
        $params = array(
            "P_CDEMPRESA"  => $cdempresa,
            "P_CDINSCMUNI" => $cdinscmuni,
            "P_NRORG"      => $nrorg
        );

        $dataset = self::getSenhasCriptografadas($connection, $params);
        if (is_array($dataset) && count($dataset) > 0) {
            $senhaCriptografada = $dataset[0]["CDSENHACERTDIG"];
            return self::decrypt($senhaCriptografada);
            //return UtilGeral::decrypt($senhaCriptografada);
        }
        else return null;
    }
    
    private static function getSenhasCriptografadas($connection, $params) {
        $sql = "SELECT CDSENHACERTDIG, CDSENHAACESSOWS
                  FROM PARAMNFSEINSCMUNI
                 WHERE CDEMPRESA  = :P_CDEMPRESA
                   AND CDINSCMUNI = :P_CDINSCMUNI
                   AND NRORG      = :P_NRORG
                   AND IDATIVO    = 'S'";

        $std = $connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public static function zGravaFile(
        $fileUploader,
        $tpAmb = '2',
        $filename = '',
        $data = '',
        $subFolder = 'temporarias',
        $cnpj,
        $ie,
        $chNFe = ''
    ) {
        
        $tmpFile = sys_get_temp_dir().DIRECTORY_SEPARATOR.'xmlNota'.uniqid().'.xml';
        file_put_contents($tmpFile, $data);
        $file = file_get_contents($tmpFile);
        $file    = base64_encode($file);

        $file = 'data: '.mime_content_type($tmpFile).';base64,'.$file;
        
        $lastModify = filectime($tmpFile);

        $file = array(
            "name" => $filename, 
            "lastModified" => $lastModify,
            "lastModifiedDate" => '',
            "webkitRelativePath" => '',
            "type" => '',
            "size"  => filesize($tmpFile),
            "b64File" => $file);
            
            
        $row['XML']    = array();
        $row['XML'][0] = $file;
        
        $subFolder .= date("Ym");
        
        $fileUploader->uploadFilesInRow($row, 'XML', $subFolder);
        unlink($tmpFile);
        
        $fileServerLink = $row['XML'][0]['path'];
        
        $subFolder = ($tpAmb == 1) ? 'producao/'.$subFolder : 'homologacao/'.$subFolder;
        
        $this->insertIntoRelacFileServer($chNFe, $subFolder, $fileServerLink);
        
        return $row['XML'][0]['path'];
        
    }
    
    private function insertIntoRelacFileServer($chNFe, $diretorio, $fileServerLink) {

        $sql = "INSERT
                INTO RELACFILESERVER
                  (
                    CDRELAC,
                    DIRETORIO,
                    FILESERVERLINK,
                    NRORG
                  )
                  VALUES
                  (
                    :CDRELAC,
                    :DIRETORIO,
                    :FILESERVERLINK,
                    :NRORG
                  )";
        
        $params = array(
            "CDRELAC"        => $chNFe,
            "DIRETORIO"      => $diretorio,
            "FILESERVERLINK" => $fileServerLink,
            "NRORG"          => $this->environment->getNrOrgTrab()
        );

        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public static  function GetUltimoRegistro( $connection,$cdfilial, $nrorg){
         $sql = "SELECT
                    MAX(DTULTATU)
                FROM
                    INTG_NOTAFISCAL
                WHERE 
                    IDDOCFISCELE = '02'";


        $std = $connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
        
        
    }
    
       public static function existeNotaRelac($chave, $connection) {
        $sql = "SELECT * FROM RELACFILESERVER WHERE CDRELAC = :NRACESSONFE AND DIRETORIO LIKE 'homologacao/importar%'";
        
        $params = array(
            "NRACESSONFE"        => $chave,
        );

        $std = $connection->prepare($sql);
        $std->execute($params);
		return $std->fetchAll();  
    }
    
    public static function fomataValor($str, $pos, $c){
        return substr($str, 0, $pos) . $c . substr($str, $pos);
    }


    
}